@@ -1,16 +1,18 @@
+use crate::common::is_starting_ident_char;
 use crate::describe::ast::DescribeAST;
 
+use ::proc_macro2::Ident;
 use ::proc_macro2::TokenStream;
 use ::quote::format_ident;
 use ::quote::quote;
 
 pub fn build(ast: DescribeAST) -> TokenStream {
-    let test_description = format_ident!("{}", &ast.description);
+    let description_ident = build_description_ident(&ast.description);
     let code_block = &ast.code_block;
 
     quote! {
       #[cfg(test)]
-      mod #test_description {
+      mod #description_ident {
           use super::*;
 
           #code_block
@@ -18,6 +20,20 @@ pub fn build(ast: DescribeAST) -> TokenStream {
     }
 }
 
+fn build_description_ident(description: &str) -> Ident {
+    let c = description
+        .chars()
+        .into_iter()
+        .next()
+        .expect("Empty description given (this should never happen)");
+
+    if is_starting_ident_char(c) {
+        format_ident!("{description}")
+    } else {
+        format_ident!("_{description}")
+    }
+}
+
 #[cfg(test)]
 mod build {
     use super::*;
