@@ -1,4 +1,6 @@
+use ::syn::Path;
+
 pub struct TestCaseAST {
     pub test_description: String,
-    pub test_name: String,
+    pub test_name: Path,
 }
